A type-safe interface over DB column families.
Traits
- KeyCodec
- This trait defines a type that can serve as a
Schema::Key. - KeyDecoder
- Implementors of this trait can be used to decode keys in the given
Schema. - KeyEncoder
- Implementors of this trait can be used to encode keys in the given
Schema. - Schema
- A
Schemais a type-safe interface over a specific column family in aDB. It always a key type (KeyCodec) and a value type (ValueCodec). - Value
Codec - This trait defines a type that can serve as a
Schema::Value.
Type Aliases
- Column
Family Name - Crate users are expected to know column
family
names beforehand, so they can have
staticlifetimes. - Result
- A
core::result::Resultalias withCodecErroras the error type.